burns negative emotion log for feeling good

each subgraph can have an
entrance and exit or
start and finish or
init and final or
start and done or
if and break
admit and goal

change default to init

6 subflows

## log process
1. trigger: describe upsetting event 
2. emotion: record negative feelings
3. automatic thoughts and score
4. identify distortions
5. rational explanation
6. rerate automatic thoughts

## 4. distortions
1. Black/white thinking
2. overgeneralization
3. filter out, ignore positives 
4. discounting positives ("don't count")
5. jump to conclusions. 5a) mind reading, 5b) fortune tellingt
6. magnification/minimization blow things out of proportion
7. emotion as reason: "i feel like an idiot so i am one. i don't feel like doing it so i won't"
8. should/n't must/n't ought/not have to: self and others
9. labels: I'm a fool, I'm a jerk, I'm a loser
10. personalization and blame: blame yourself for something you aren't entirely responsible for
 

1. angry, want to punch the headboard because i may have jeopardized privacy of myan user data
2. anger, frustration, regret, Shane, embarrassment, guilt
3. customer might find out and Shame me publicly .7 or Maria might get upset .8 or interns might think badly of us as company .6 onow might cancel our contact .7 or sue us .4
4. catastrophizing c
5. customer has their hands full protecting their partners family in Myanmar
6. rerate .5 
burns negative emotion log for feeling good

each subgraph can have an
entrance and exit or
start and finish or
init and final or
start and done or
if and break
admit and goal

change default to init

6 subflows

## log process
1. trigger: describe upsetting event 
2. emotion: record negative feelings
3. automatic thoughts and score
4. identify distortions
5. rational explanation
6. rerate automatic thoughts

## 4. distortions
1. Black/white thinking
2. overgeneralization
3. filter out, ignore positives 
4. discounting positives ("don't count")
5. jump to conclusions. 5a) mind reading, 5b) fortune tellingt
6. magnification/minimization blow things out of proportion
7. emotion as reason: "i feel like an idiot so i am one. i don't feel like doing it so i won't"
8. should/n't must/n't ought/not have to: self and others
9. labels: I'm a fool, I'm a jerk, I'm a loser
10. personalization and blame: blame yourself for something you aren't entirely responsible for
 

1. angry, want to punch the headboard because i may have jeopardized privacy of myan user data
2. anger, frustration, regret, Shane, embarrassment, guilt
3. customer might find out and Shame me publicly .7 or Maria might get upset .8 or interns might think badly of us as company .6 onow might cancel our contact .7 or sue us .4
4. catastrophizing c
5. customer has their hands full protecting their partners family in Myanmar
6. rerate .5 
burns negative emotion log for feeling good

each subgraph can have an
entrance and exit or
start and finish or
init and final or
start and done or
if and break
admit and goal

change default to init

6 subflows

## log process
1. trigger: describe upsetting event 
2. emotion: record negative feelings
3. automatic thoughts and score
4. identify distortions
5. rational explanation
6. rerate automatic thoughts

## 4. distortions
1. Black/white thinking
2. overgeneralization
3. filter out, ignore positives 
4. discounting positives ("don't count")
5. jump to conclusions. 5a) mind reading, 5b) fortune tellingt
6. magnification/minimization blow things out of proportion
7. emotion as reason: "i feel like an idiot so i am one. i don't feel like doing it so i won't"
8. should/n't must/n't ought/not have to: self and others
9. labels: I'm a fool, I'm a jerk, I'm a loser
10. personalization and blame: blame yourself for something you aren't entirely responsible for
 

 1. angry, want to punch the headboard because i may have jeopardized privacy of myan user data
 2. anger, frustration, regret, Shane, embarrassment, guilt
 3. customer might find out and Shame me publicly .7 or Maria might get upset .8 or interns might think badly of us as company .6 onow might cancel our contact .7 or sue us .4
 4. catastrophizing c
 5. customer has their hands full protecting their partners family in Myanmar
 6. rerate .5 
 
